@@ -1,4 +1,4 @@
-# sumFREGAT (2017-2018) Gulnara R. Svishcheva & Nadezhda M. Belonogova, ICG SB RAS
+# sumFREGAT (2017-2021) Gulnara R. Svishcheva & Nadezhda M. Belonogova, ICG SB RAS
 
 sumstat.SKAT <- function(obj) {
 
@@ -24,11 +24,18 @@ sumstat.SKAT <- function(obj) {
 
 }
 
-
 'SKAT' <- function (score.file, gene.file, genes = 'all', cor.path = 'cor/', anno.type = '', beta.par = c(1, 25), weights.function = NULL,
 user.weights = FALSE, gen.var.weights = 'se.beta', method = 'kuonen', acc = 1e-8, lim = 1e+6, rho = FALSE,
 p.threshold = 0.8, write.file = FALSE, quiet = FALSE) {
 
+	do.call(SKAT.int, c(as.list(environment()), prob = NA, phred = NA))
+
+}
+
+SKAT.int <- function (score.file, gene.file, genes = 'all', cor.path = 'cor/', anno.type = '', beta.par = c(1, 25), weights.function = NULL,
+user.weights = FALSE, gen.var.weights = 'se.beta', method = 'kuonen', acc = 1e-8, lim = 1e+6, rho = FALSE,
+p.threshold = 0.8, write.file = FALSE, quiet = FALSE, prob = NA, phred) {
+
 ############ COMMON CHECKS
 
 tmp <- check.input(score.file, cor.path, gene.file, genes)
@@ -42,6 +49,7 @@ for (i in 1:length(tmp)) assign(names(tmp)[i], tmp[[i]])
 tmp <- check.spec.SKAT(method, rho)
 for (i in 1:length(tmp)) assign(names(tmp)[i], tmp[[i]])
 
+if (!is.na(prob)) user.weights <- prob
 check.list <- get.check.list('SKAT', score.file, anno.type, user.weights, gen.var.weights, fweights, rho)
 
 ############ ANALYSIS
@@ -49,7 +57,7 @@ check.list <- get.check.list('SKAT', score.file, anno.type, user.weights, gen.va
 obj0 <- sapply(c('method', 'acc', 'lim', 'rhos', 'p.threshold'),
 	function(x) get(x), simplify = FALSE, USE.NAMES = TRUE)
 
-genewise(score.file, gene.file, gf, anno.type, cor.path, cor.file.ext, check.list, write.file, obj0, ncl = 3, NULL, gen.var.weights, fweights, rho = rho, quiet = quiet, test = 'SKAT')
+genewise(score.file, gene.file, gf, anno.type, cor.path, cor.file.ext, check.list, write.file, obj0, ncl = 3, NULL, gen.var.weights, fweights, rho = rho, quiet = quiet, phred = phred, test = 'SKAT')
 
 }
 
