@@ -3,7 +3,9 @@
 'sumchi' <- function (score.file, gene.file, genes = 'all', cor.path = 'cor/',
 anno.type = '', method = 'kuonen', acc = 1e-8, lim = 1e+6, write.file = FALSE, quiet = FALSE) {
 
-	SKAT(score.file, gene.file, genes, cor.path, anno.type, beta.par = c(1, 1), weights.function = NULL,
-	user.weights = FALSE, gen.var.weights = 'none', method, acc, lim, write.file = write.file, quiet = quiet)
+	my.args <- c(as.list(environment()), weights.function = NULL,
+		user.weights = FALSE, gen.var.weights = 'none', prob = NA, phred = NA)
+	my.args$beta.par <- c(1, 1) 
+	do.call(SKAT.int, my.args)
 
 }
\ No newline at end of file
